# Security Reporting Tool

<!-- Badges -->
[![Documentation](https://img.shields.io/badge/Documentation-SeReTo-blue)](https://sereto.s4n.cz/)
[![PyPI](https://img.shields.io/pypi/v/sereto?label=PyPI)](https://pypi.org/project/sereto/)

<picture>
  <source media="(prefers-color-scheme: dark)" srcset="https://raw.githubusercontent.com/s3r3t0/sereto/main/docs/assets/logo/sereto_block_white.svg">
  <source media="(prefers-color-scheme: light)" srcset="https://raw.githubusercontent.com/s3r3t0/sereto/main/docs/assets/logo/sereto_block_black.svg">
  <img alt="SeReTo logo" src="https://raw.githubusercontent.com/s3r3t0/sereto/main/docs/assets/logo/sereto_block_black.svg" height="300">
</picture>

## Getting Started

```bash
uv tool install sereto
```

> Instead of `uv` you can use can use alternative package manager, e.g. `pip install sereto`.

For more information, please visit the [documentation](https://sereto.s4n.cz/getting_started/installation/).


> Created with support of [NN Management Services, s.r.o.](https://www.nn.cz/kariera/en/nn-digital-hub/)
